<?php

namespace BeycanPress\Licensor;

use \Beycan\Response;
use \Beycan\EnvatoLicenseChecker;
use \BeycanPress\Licensor\Models\License;

class Api extends PluginHero\Api
{
    public function __construct()
    {
        $this->addRoutes([
            'licensor-api' => [
                'verify' => [
                    'callback' => 'verify',
                    'methods' => ['POST']
                ],
            ]
        ]);
    }

    /**
     * @param WP_REST_Request $request
     * @return void
     */
    public function verify($request)
    {
		if (!$licenseCode = $request->get_param('licenseCode')) {
            Response::badRequest("License code not found!", "LCNF");
		}

        if (!$productCode = $request->get_param('productCode')) {
            Response::badRequest("Product code not found!", "PCNF");
		}
		
        $pattern = '/^[a-zA-Z0-9-]*$/m';
        preg_match_all($pattern, $licenseCode, $matches, PREG_SET_ORDER, 0);

        $pattern2 = '/^[a-zA-Z0-9-]{8}-[a-zA-Z0-9-]{4}-[a-zA-Z0-9-]{4}-[a-zA-Z0-9-]{4}-[a-zA-Z0-9-]{12}/m';
        preg_match_all($pattern2, $licenseCode, $matches2, PREG_SET_ORDER, 0);

        if (!$matches || !$matches2) {
            Response::badRequest("Invalid license code format!", "ILCF");
        }

        if (!$domain = $this->parseDomain($request->get_header('referer'))) {
            Response::badRequest("Domain not found!", "DNF");
        }		
        
        $licenseModel = new License();
        $license = $licenseModel->findOneBy(['licenseCode' => $licenseCode]);

        if (in_array($domain, explode(',', $this->setting('excludedDomains')))) {
            $license->expireTime = null;
            Response::success("Valid license", $license);
        }

        if ($this->setting('envatoApiKey')) {
            EnvatoLicenseChecker::setBearerToken($this->setting('envatoApiKey'));
            $envatoLicense = EnvatoLicenseChecker::check($licenseCode);

            if (!$envatoLicense) {
                if (!$license) {
                    Response::notFound("Invalid license!", "IL");
                }
    
                if ($license->placeOfPurchase == 1) {
                    $licenseModel->update(
                        [
                            'status' => 2
                        ],
                        [
                            'status' => 1,
                            'licenseCode' => $licenseCode,
                        ]
                    );
    
                    Response::notFound("License revoked by CodeCanyon!", "LRBC");
                }
            } elseif ($envatoLicense) {
                if (!$license) {
                    $licenseTypeEnums = $this->setting('licenseTypeEnums');
                    if ($envatoLicense !== null && $licenseTypeEnums) {;
                        $licenseTypeEnumIndex = array_search($envatoLicense->license, array_column($licenseTypeEnums, 'licenseType'));
                        $licenseType = (int) $licenseTypeEnums[$licenseTypeEnumIndex]['number'] ?? 1;
                    } else {
                        $licenseType = 1;
                    }
        
                    $license = [
                        'productId' => $envatoLicense->item->id,
                        'product' => $envatoLicense->item->name,
                        'productCode' => $productCode,
                        'licenseCode' => $licenseCode,
                        'licenseType' => $licenseType,
                        'domain' => $domain,
                        'earning' => $envatoLicense->amount,
                        'support' => $envatoLicense->support_amount,
                        'buyer' => $envatoLicense->buyer,
                        'placeOfPurchase' => 1,
                        'status' => 1,
                        'soldAt' => $envatoLicense->sold_at
                    ];
        
                    $licenseModel->insert($license);
                }

                Response::success("Valid license", $license);
            }
        }

        if ($license) {

            $updateData = [];

            if (!$license->domain) {
                $license->domain = $domain;
                $updateData['domain'] = $domain;
            }

            if (!$license->productCode) {
                $license->productCode = $productCode;
                $updateData['productCode'] = $productCode;
            }

            if (!empty($updateData)) {
                $licenseModel->update($updateData, [
                    'licenseCode' => $licenseCode,
                ]);
            }

            
            if ($license->expireTime && time() > strtotime($license->expireTime)) {
                Response::notFound("Expired license!", "EL");
            }

            if ($license->status == 2) {
                Response::notFound("Deactivated license!", "DL");
            }

            if ($license->licenseType != 1 || $license->licenseType != 6 && !in_array($domain, explode(',', $license->domain))) {
                Response::error("This license is already registered for another domain.", null, "ANDO");
            }

            if ($license->productCode != $productCode) {
                Response::error("This license key is registered for another product!", null, "ANPR");
            }
        } else {
            Response::notFound("Invalid license!", "IL");
        }

        Response::success("Valid license", $license);
    }

}
