<?php 

namespace BeycanPress\Licensor\Pages;

use BeycanPress\Licensor\LicenseCreator;
use BeycanPress\Licensor\Models\License;
use BeycanPress\Licensor\PluginHero\Page;

/**
 * Create license page
 */
class CreateLicense extends Page
{   
    private $model;

    /**
     * Class construct
     * @return void
     */
    public function __construct()
    {
        $this->model = new License();
        
        if (isset($_POST['create'])) {
            $this->createLicense();
        }

        $parent = $this->pages->LicenseList->slug;
        parent::__construct([
            'pageName' => esc_html__('Create license', 'licensor'),
            'parent' => $parent
        ]);
    }

    /**
     * @return void
     */
    public function page()
    {
        $this->viewEcho('pages/license/create');
    }

    /**
     * @return void
     */
    private function createLicense() 
    {
        $licenseData = $_POST;

        if (isset($licenseData['expireTime'])) {
            $licenseData['expireTime'] = sanitize_text_field($licenseData['expireTime']);
        }

        $licenseData = array_map('sanitize_text_field', $licenseData);
        $licenseData['email'] = sanitize_email($licenseData['email']);
        $licenseData['earning'] = floatval($licenseData['earning']);
        $licenseData['support'] = floatval($licenseData['support']);
        $licenseData['productId'] = absint($licenseData['productId']);
        $licenseData['licenseType'] = absint($licenseData['licenseType']);
        $licenseData['soldAt'] = date('Y-m-d H:i:s');
        $licenseData['placeOfPurchase'] = absint($licenseData['placeOfPurchase']);

        unset($licenseData['create']);
        
        $this->insert($licenseData);
    }

    /**
     * @param array $licenseData
     * @return void
     */
    private function insert(array $licenseData) : void
    {
        $licenseData['licenseCode'] = LicenseCreator::create();
        $this->model->insert(array_merge($licenseData, ['status' => 1]));
        $this->adminRedirect($this->pages->LicenseList->getUrl() . '&added=1');
    }
}