<?php

namespace BeycanPress\Licensor;

use \BeycanPress\Licensor\PluginHero\Setting;
use \BeycanPress\Licensor\PluginHero\Helpers;

class Settings extends Setting
{
    use Helpers;
    
    public function __construct()
    {
        $parent = $this->pages->LicenseList->slug;

        parent::__construct(esc_html__('Settings', 'licensor'), $parent);

        $this->licensed();

        self::createSection(array(

            'id'     => 'general_options', 
            'title'  => esc_html__('General options', 'licensor'),
            'icon'   => 'fa fa-cog',
            'fields' => array(
                array(
                    'id'      => 'dds',
                    'title'   => esc_html__('Data deletion status', 'licensor'),
                    'type'    => 'switcher',
                    'default' => false,
                    'help'    => esc_html__('This setting is passive come by default. You enable this setting. All data created by the plug-in will be deleted while removing the plug-in.', 'licensor')
                ),
                array(
                    'id'      => 'myLicensesPage',
                    'title'   => esc_html__('My account my license page', 'licensor'),
                    'type'    => 'switcher',
                    'default' => true,
                    'help'    => esc_html__('Activate if you want the my licenses page to appear on the WooCommerce my account page.', 'licensor')
                ),
                array(
                    'id'      => 'licenseInfoOrderPage',
                    'title'   => esc_html__('Order page license info', 'licensor'),
                    'type'    => 'switcher',
                    'default' => true,
                    'help'    => esc_html__('Activate if you want license information to be displayed on the order page..', 'licensor')
                ),
                array(
                    'id'      => 'envatoApiKey',
                    'title'   => esc_html__('Envato API key', 'licensor'),
                    'type'    => 'text',
                    'help'    => esc_html__('API key generated by Envato API', 'licensor'),
                    'sanitize' => function($val) {
						return sanitize_text_field($val);
					},
                    'validate' => function($val) {
                        $val = sanitize_text_field($val);
                        if (empty($val)) {
                            return esc_html__('Envato API key address cannot be empty.', 'licensor');
                        } elseif (strlen($val) < 32 || strlen($val) > 32) {
                            return esc_html__('Envato API key address must consist of 32 characters.', 'licensor');
                        }
                    }
                ),
                array(
                    'id'      => 'excludedDomains',
                    'title'   => esc_html__('Excluded domains', 'licensor'),
                    'type'    => 'textarea',
                    'help'    => esc_html__('For example, "localhost" comes by default. Enter the domains you want to exempt from the license verification process, separated by a comma (,) as an example: beycanpress.com,service.beycanpress.com', 'licensor'),
                    'default' => 'localhost'
                ),
                array(
                    'id'        => 'licenseTypeEnums',
                    'type'      => 'group',
                    'title'     => esc_html__('License type enums', 'licensor'),
                    'fields'    => array(
                        array(
                            'id'    => 'licenseType',
                            'type'  => 'text',
                            'title' => esc_html__('License type', 'licensor'),
                            'sanitize' => function($val) {
                                return sanitize_text_field($val);
                            },
                        ),
                        array(
                            'id'    => 'number',
                            'type'  => 'number',
                            'title' => esc_html__('Number', 'licensor'),
                        ),
                    ),
                    'default' => [
                        [
                            'licenseType' => 'Regular License',
                            'number' => 1
                        ],
                        [
                            'licenseType' => 'Extended License',
                            'number' => 2
                        ]
                    ]
                ),
            )
        ));
    }

}