<?php

namespace BeycanPress\Licensor\WooCommerce;

use BeycanPress\Licensor\PluginHero\Helpers;

class MetaBox
{
    use Helpers;

    /**
     * Class construct
     * @return void
     */
    public function __construct()
    {
        add_action('post_updated', array($this, 'saveLicensorProductType'), 10, 3);

        add_action('add_meta_boxes', function() {
            add_meta_box(
                'mtLicensorProductType',
                esc_html__('Licensor Product Type', 'licensor'),
                array($this, 'licensorProductType'),
                'product',
                'side',
                'high'
            );
        });
    }


    /**
     * @param object $post
     * @return void
     */
    public function licensorProductType(object $post) : void
    {
        $this->createNewNonceField();
        $licensorProductType = get_post_meta($post->ID, 'licensorProductType', true);

        $this->viewEcho('product-type', ['licensorProductType' => $licensorProductType]);
    }

    /**
     * @param integer $postId current post
     * @param object $postAfter post savad after data
     * @return int
     */
    function saveLicensorProductType(int $postId, object $postAfter) : int
    {
        if (!$this->verifier($postId, $postAfter)) {
            return $postId;
        }
    
        $licensorProductType = isset($_POST['licensorProductType']) ? sanitize_text_field($_POST['licensorProductType']) : null;

        update_post_meta($postId, 'licensorProductType', $licensorProductType);
        
        return $postId;
    }

    /**
     * @param integer $postId current post
     * @param object $postAfter post savad after data
     * @return boolean
     */
    private function verifier(int $postId, object $postAfter) : bool
    {
        // Permission control
        $postType = get_post_type_object($postAfter->post_type);
        if (!current_user_can($postType->cap->edit_post, $postId)) {
            return false;
        }

        // Post type control
        if(!in_array($postAfter->post_type, ['product'])) {
            return false;
        }

        // Autosave control
        if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
            return false;
        }

        return true;
    }

}